@@ -34,9 +34,9 @@ use Moose;
 use LWP;
 use Carp;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
-my $base_url = 'http://api.guardianapis.com/';
+my $base_url = 'http://content.guardianapis.com/';
 
 has 'ua' => (
     is => 'rw',
@@ -59,8 +59,8 @@ has 'format' => (
 
 =head2 new({ api_key => $key [, format => '(xml|json)'] })
 
-Create a new Guardian::OpenPlatform::API object. Takes a reference to a
-hash of arguments. This hash has one mandatory key and one optional key.
+Create a new L<Guardian::OpenPlatform::API> object.Takes a reference to a hash of
+arguments. This hash has one mandatory key and one optional key.
 
 =over 4
 
@@ -70,16 +70,15 @@ This item is mandatory. The value should be your Guardian API access key.
 
 =item format
 
-This item is optional. It defines the default format for the data that you
-get back from the Guardian. Valid values are 'json' or 'xml'. If this
-argument is omitted then it 'json' is used.
+This item is an optional. It defines the default format for the data that you get
+back from the Guardian. Valid values are 'json' or 'xml'. Default is 'json'.
 
 =back
 
 =head2 content({ qry => $query, [ filter => $filter, format => $fmt ] });
 
-Request content from the Guardian. Takes a reference to a hash of arguments.
-This hash has one mandatory key and two optional keys.
+Request content from the Guardian. Takes a reference to a hash of arguments. This
+hash has one mandatory key and two optional keys.
 
 =over 4
 
@@ -89,16 +88,15 @@ This item is mandatory. Defines the the text that you want to get data about.
 
 =item filter
 
-This item is optional. Defines filters to be applied to your query. If you
-have a single query then the value can be a single scalar value. If you have
-multiple queries, then the value can be a reference to an array of scalar
-values.
+This item is optional. Defines filters to be applied to your query. If you have a
+single query  then  the  value can be a single scalar value. If you have multiple
+queries, then the value can be a reference to an array of scalar values.
 
 =item format
 
-This item is optional. Defines the data format that you want to get back.
-This can be either 'json' or 'xml'. If no value is given then the default
-format given to the C<new> method is used.
+This item is optional. Defines the data format that you want to get back.This can
+be either 'json' or 'xml'. If no value is given then the default format  given to
+the C<new> method is used.
 
 =back
 
@@ -134,10 +132,9 @@ Currently does the same as C<content>. Will get more complex though.
 
 sub search {
     my $self = shift;
-
     my $args = shift;
 
-    my $url = $base_url . "content/search?q=$args->{qry}";
+    my $url = $base_url . "search?q=$args->{qry}";
 
     if ($args->{filter}) {
 	unless (ref $args->{filter}) {
@@ -153,13 +150,12 @@ sub search {
 
     my $fmt = $args->{format} || $self->format;
     $url .= "&format=$fmt";
-
-    $url .= '&api_key=' . $self->api_key;
+    $url .= '&api-key=' . $self->api_key;
 
     my $resp = $self->{ua}->get($url);
 }
 
-=head2 tags
+=head2 tags(\%params)
 
 Returns information about tags.
 
@@ -167,11 +163,9 @@ Returns information about tags.
 
 sub tags {
     my $self = shift;
-
     my $args = shift;
 
-    my $url = $base_url . 'content/tags';
-
+    my $url = $base_url . 'tags';
     my $params;
     if ($args->{qry}) {
         $url .= "?q=$args->{qry}";
@@ -183,12 +177,12 @@ sub tags {
     $url .= $params ? '&' : '?';
     $url .= "format=$fmt";
 
-    $url .= '&api_key=' . $self->api_key;
+    $url .= '&api-key=' . $self->api_key;
 
     my $resp = $self->{ua}->get($url);
 }
 
-=head2 item
+=head2 item(\%params)
 
 Returns a content item given its id.
 
@@ -196,16 +190,13 @@ Returns a content item given its id.
 
 sub item {
     my $self = shift;
-
     my $args = shift;
 
-    my $url = $base_url . "content/item/$args->{item}";
-
+    my $url = $base_url . "item/$args->{item}";
     my $fmt = $args->{format} || $self->format;
 
     $url .= "?format=$fmt";
-
-    $url .= '&api_key=' . $self->api_key;
+    $url .= '&api-key=' . $self->api_key;
 
     my $resp = $self->{ua}->get($url);
 }
@@ -228,45 +219,36 @@ This is really just a simple proof of concept. It will get better, I promise.
 
 =head1 BUGS, REQUESTS, COMMENTS
 
-Support for this module is supplied using the CPAN RT system via the web or 
-email:
+Support for this module is supplied using the CPAN RT system via the web / email:
 
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Guardian::OpenPlatform::API>
 
 bug-guardian-openplatform-api@rt.cpan.org
 
-This makes it much easier for me to track things and thus means your problem
-is less likely to be neglected.
+This  makes it much easier for me to track things and thus means your problem is
+less likely to be neglected.
 
-=head1 SOURCE CODE
+=head1 REPOSITORY
 
-Source code for this module is available on GitHub at
-
-=over 4
-
-=item *
-
-http://github.com/davorg/guardian-openplatform-api/
-
-=back
-
-Please feel free to clone, fork and otherwise play with it.
+L<https://github.com/manwar/guardian-openplatform-api>
 
 =head1 LICENCE AND COPYRIGHT
 
 Copyright (c) Magnum Solutions Ltd., 2009. All rights reserved.
 
-This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself, either Perl version 5.000 or, at your option,
-any later version of Perl 5 you may have available.
+This library is free software; you can redistribute it and/or modify it under the
+same terms as Perl itself, either Perl version 5.000 or, at your option,any later
+version of Perl 5 you may have available.
 
-The full text of the licences can be found in perlartistic and perlgpl as
-supplied with Perl 5.8.1 and later.
+The full text of the licences can be found in perlartistic and perlgpl as supplied
+with Perl 5.8.1 and later.
 
 =head1 AUTHOR
 
 Dave Cross, E<lt>dave@mag-sol.comE<gt>
 
+Currently maintained by Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
+
 =cut
 
 1;
